﻿using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Windows;
using ThinkGeo.MapSuite;
using ThinkGeo.MapSuite.Drawing;
using ThinkGeo.MapSuite.Layers;
using ThinkGeo.MapSuite.Shapes;
using ThinkGeo.MapSuite.Styles;
using ThinkGeo.MapSuite.Wpf;

namespace _9571
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void map_Loaded(object sender, RoutedEventArgs e)
        {
            map.MapUnit = GeographyUnit.DecimalDegree;

            LayerOverlay layerOverlay = new LayerOverlay();
            ShapeFileFeatureLayer shapeFileLayer = new ShapeFileFeatureLayer(@"..\..\AppData\states.shp");            
            shapeFileLayer.ZoomLevelSet.ZoomLevel01.CustomStyles.Add(new CustomStyle());
            shapeFileLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            layerOverlay.Layers.Add(shapeFileLayer);
            map.Overlays.Add(layerOverlay);

            shapeFileLayer.Open();
            map.CurrentExtent = shapeFileLayer.GetBoundingBox();
            map.Refresh();
        }
    }

    public class CustomStyle : PointStyle
    {
        protected override void DrawCore(IEnumerable<Feature> features, GeoCanvas canvas, Collection<SimpleCandidate> labelsInThisLayer, Collection<SimpleCandidate> labelsInAllLayers)
        {
            foreach (Feature feature in features)
            {
                //if (feature is VehicleFeature) //if the feature is my custom type VehicleFeature which inherits from Feature
                {
                    PointShape location = feature.GetShape().GetCenterPoint(); //get the pointshape from the feature

                    var packageColor = new GeoPen(GeoColors.Red)
                    {
                        DashStyle = LineDashStyle.Dash
                    };

                    Collection<Vertex> vertices = new Collection<Vertex> { new Vertex(location), new Vertex(0, 0) };
                    LineShape connectingLine = new LineShape(vertices); //create the connecting line

                    //draw to the map
                    canvas.DrawLine(connectingLine, packageColor, DrawingLevel.LevelOne);
                    EllipseShape es = new EllipseShape(location, 30, ThinkGeo.MapSuite.GeographyUnit.DecimalDegree, DistanceUnit.Meter);
                    canvas.DrawArea(es, packageColor, DrawingLevel.LevelOne);
                }
            }
            base.DrawCore(features, canvas, labelsInThisLayer, labelsInAllLayers);
        }
    }
}
